@@ -1,6 +1,5 @@
 import json
 
-
 # The BPMN-RPA Set_Value module is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -13,6 +12,8 @@ import json
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
+import uuid
+
 
 def value_to_variable(value: any, convert_to_list=False) -> any:
     """
@@ -32,6 +33,24 @@ def value_to_variable(value: any, convert_to_list=False) -> any:
     return value
 
 
+def json_to_object(json_string: str) -> any:
+    """
+    Convert a JSON string to an Object.
+    :param json_string: The JSON string to convert.
+    :return: The Object from the JSON string.
+    """
+    return json.loads(json_string)
+
+
+def object_to_json(object: any) -> str:
+    """
+    Convert an Object to a JSON string.
+    :param object: The Object to convert.
+    :return: The JSON string.
+    """
+    return json.dumps(object)
+
+
 def split_string_to_list(string: str, separator: str = " ", maxsplit: int = -1) -> list:
     """
     Convert a string with a separator to a list.
@@ -66,3 +85,11 @@ def increment_counter(counter: any, step: int = 1) -> any:
         newcounter = 0
 
     return newcounter
+
+
+def create_unique_id():
+    """
+    Generate a unique ID
+    :return: Unique ID as string
+    """
+    return uuid.uuid4().hex
